@@ -21,7 +21,7 @@ import weakref
 import functools
 import operator
 
-__version__ = "0.4.0"  # automatically patched by setup.py when packaging
+__version__ = "0.4.1"  # automatically patched by setup.py when packaging
 
 # from six.py's strategy
 INTEGER_TYPES = None
@@ -62,7 +62,7 @@ class ThreadingTCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
 
 
 DEFAULT_HOST = "127.0.0.1"
-DEFAULT_SERVER_PORT = 4768  # "Gh"
+DEFAULT_SERVER_PORT = 27238  # 0x6a66 = "jf"
 
 VERSION = "v"
 MAX_VERSION = "max_v"
@@ -1096,6 +1096,7 @@ class BridgeServer(threading.Thread):
 
         Like a thread, so call run() to run directly, or start() to run on a background thread
     """
+    is_serving = False
 
     def __init__(self, server_host=DEFAULT_HOST, server_port=0, loglevel=None, response_timeout=DEFAULT_RESPONSE_TIMEOUT):
         """ Set up the bridge.
@@ -1115,7 +1116,6 @@ class BridgeServer(threading.Thread):
         self.server.bridge = weakref.proxy(self)
         self.server.timeout = 1
         self.daemon = True
-        self.is_serving = False
 
         logging.basicConfig()
         self.logger = logging.getLogger(__name__)
@@ -1469,7 +1469,6 @@ class BridgedModuleFinderLoader:
 
     def path_hook_fn(self, path):
         """ Called when the import machinery runs over path_hooks - returns itself as a finder if its this bridge connection """
-        print(path)
         if path == repr(self.bridge_client.client):
             return self
         # not us, don't play along
@@ -1522,6 +1521,11 @@ class BridgedModuleFinderLoader:
         # set some import machinery fields
         target._bridge_set_override("__loader__", self)
         target._bridge_set_override("__package__", parent)
+        # ensure we have an override set on __spec__ for everything, including non-modules (e.g., BridgedCallables on java classes)
+        # otherwise, __spec__ gets set by import machinery later, leading to a client handle being pushed into the server, where other
+        # clients might get it if they import the same module
+        # TODO probably need to check there's nothing else being set against the modules? Or is there a way to reload modules for each new client?
+        target._bridge_set_override("__spec__", None)
 
         # add the module to sys.modules
         sys.modules[fullname] = target
